export declare const brackets: RegExp;
export declare const whitespace: RegExp;
export declare const reservedOps: RegExp;
export declare const trailingWhitespace: RegExp;
export declare namespace Schema {
    type Common = {
        multi?: boolean;
    };
    type WithBlock = {
        block?: Block;
    };
    type Hash = {
        type: 'hash';
        schema: Record<string, t>;
    };
    type Array = {
        type: 'array';
        schema: Record<string, t>;
    };
    type Block = Hash | Array;
    type BasicType = {
        type: 'num';
    } | {
        type: 'str';
    } | {
        type: 'bool';
    };
    type t = BasicType & Common & WithBlock | Block & Common | {
        type: 'kv';
    } & Common | {
        type: 'enum';
        options: string[];
    } & Common | {
        type: 'list';
    } & Common & WithBlock | {
        type: 'tuple';
        schema: BasicType[];
    } & Common & WithBlock;
}
export declare const validTypes: string[];
export declare const BLOCKABLE_TYPES: string[];
export declare function basicTypeFromName(name: string): Schema.BasicType | null;
declare type ZamlErrorType = 'syntax-error' | 'author-error' | 'user-error' | 'unexpected-error';
export declare class ZamlError extends Error {
    type: ZamlErrorType;
    pos: Pos | null;
    static syntax(pos: Pos, char: string, more?: string): ZamlError;
    constructor(type: ZamlErrorType, pos: Pos | null, message: string);
    addSource(source: string): void;
}
export declare function isObj(x: any): boolean;
export declare function unexp(char: string, more?: string): string;
export declare class Pos {
    line: number;
    col: number;
    i: number;
    constructor(line?: number, col?: number, i?: number);
    push(source: string): this;
    newcol(): this;
    newline(windowsLine?: boolean): void;
    copy(): Pos;
    skipSpace(source: string): boolean;
    skipNewline(source: string): boolean;
    skipWhitespace(source: string): boolean;
}
export {};
